@@ -2,7 +2,7 @@ package App::tmclean;
 use 5.010;
 use warnings;
 
-use version 0.77; our $VERSION = version->declare("v0.0.2");
+use version 0.77; our $VERSION = version->declare("v0.0.3");
 
 use Getopt::Long qw/GetOptions :config posix_default no_ignore_case bundling auto_help/;
 use Pod::Usage qw/pod2usage/;
@@ -81,8 +81,8 @@ sub backups2delete {
     return grep {
         chomp;
         my @paths = split m!/!, $_;
-        my $backup_date = Time::Piece->strptime($paths[-1], '%Y-%m-%d-%H%M%S');
-        $self->before_tp > $backup_date;
+        my $backup_date = eval { Time::Piece->strptime($paths[-1], '%Y-%m-%d-%H%M%S') };
+        $backup_date && $self->before_tp > $backup_date;
     } @backups;
 }
 
